%define debug_package %{nil}
Name:		splat
Version:	1.4.2
Release:	%mkrel 6
Summary:	Analyze point-to-point terrestrial RF communication links
Group:		Communications/Radio
License:	GPLv2+
URL:		https://www.qsl.net/kd2bd/splat.html
Source0:	https://www.qsl.net/kd2bd/%{name}-%{version}.tar.bz2
# Man pages for utilities, generated from utils README file
Source1:	citydecoder.man
Source2:	srtm2sdf.man
Source3:	usgs2sdf.man
Source4:	bearing.man
Source5:	postdownload.man
# Do not set -march to the cpu used to build
Patch0:		splat-1.4.2-march.parch

BuildRequires:	bzip2-devel
BuildRequires:	groff
BuildRequires:	zlib-devel

Provides:	splat-utils = %{version}-%{release}

%description
SPLAT! is a Surface Path Length And Terrain analysis application written for
Linux and Unix workstations. SPLAT! analyzes point-to-point terrestrial RF 
communication links, and provides information useful to communication system
designers and site engineers.

%prep
%setup -q
%autopatch -p1

# Fix end of line encoding
sed -i 's/\r//' utils/fips.txt

%build
# Uses custom build scripts
./build all

%install
# Build additional man pages
mkdir -p %{buildroot}%{_mandir}/man1/
groff -e -T ascii -man %{SOURCE1} > %{buildroot}%{_mandir}/man1/citydecoder.1
groff -e -T ascii -man %{SOURCE2} > %{buildroot}%{_mandir}/man1/srtm2sdf.1
groff -e -T ascii -man %{SOURCE3} > %{buildroot}%{_mandir}/man1/usgs2sdf.1
groff -e -T ascii -man %{SOURCE4} > %{buildroot}%{_mandir}/man1/bearing.1
groff -e -T ascii -man %{SOURCE5} > %{buildroot}%{_mandir}/man1/postdownload.1

# Manual install, easier than patching upstream custom install script
install -D -m 0755 %{name} %{buildroot}%{_bindir}/%{name}
install -D -m 0644 docs/english/man/%{name}.1 %{buildroot}%{_mandir}/man1/%{name}.1
install -D -m 0644 docs/spanish/man/%{name}.1 %{buildroot}%{_mandir}/es/man1/%{name}.1

# Install utils
install -D -m 0755 utils/citydecoder %{buildroot}%{_bindir}/citydecoder
install -D -m 0755 utils/bearing %{buildroot}%{_bindir}/bearing
install -D -m 0755 utils/postdownload %{buildroot}%{_bindir}/postdownload
install -D -m 0755 utils/usgs2sdf %{buildroot}%{_bindir}/usgs2sdf
install -D -m 0755 utils/srtm2sdf %{buildroot}%{_bindir}/srtm2sdf

# Rename this to avoid conflict with main readme
mv utils/README utils/README-utils

%files
%doc CHANGES COPYING README utils/README-utils utils/fips.txt
%doc sample_data
%{_bindir}/*
%{_mandir}/es/man1/*
%{_mandir}/man1/*


%changelog
* Fri Mar 18 2022 umeabot <umeabot> 1.4.2-6.mga9
+ Revision: 1797719
- Mageia 9 Mass Rebuild

* Fri Feb 14 2020 umeabot <umeabot> 1.4.2-5.mga8
+ Revision: 1517153
- Mageia 8 Mass Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 1.4.2-4.mga7
+ Revision: 1301148
- Mageia 7 Mass Rebuild

* Fri Jul 15 2016 pterjan <pterjan> 1.4.2-3.mga6
+ Revision: 1042142
- Do not set -march to the cpu used to build

* Fri Feb 19 2016 umeabot <umeabot> 1.4.2-2.mga6
+ Revision: 970427
- Mageia 6 Mass Rebuild

* Tue Oct 06 2015 barjac <barjac> 1.4.2-1.mga6
+ Revision: 886515
- new version 1.4.2

* Wed Oct 15 2014 umeabot <umeabot> 1.4.1-3.mga5
+ Revision: 740314
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.4.1-2.mga5
+ Revision: 689288
- Mageia 5 Mass Rebuild

* Thu Mar 06 2014 barjac <barjac> 1.4.1-1.mga5
+ Revision: 600604
- new version
- remove obsolete patch

* Sat Oct 19 2013 umeabot <umeabot> 1.4.0-2.mga4
+ Revision: 523193
- Mageia 4 Mass Rebuild

* Sat Mar 30 2013 barjac <barjac> 1.4.0-1.mga3
+ Revision: 406591
- clean spec
- import from fedora with thanks


* Fri Feb 15 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Jan 31 2012 Randall J. Berry, N3LRX <dp67@fedoraproject.org> - 1.4.0-1
- New upstream release. 1.4.0

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sat Aug  7 2010 Randall J. Berry <dp67@fedoraproject.org> - 1.3.0-3
- Added more macros to name and version.
- Cleanup spec
- Patch build file in utils with rpm_opt_flags
- Left rm -rf RPM_BUILD_ROOT for potential EPEL build

* Thu Aug  5 2010 Randall J. Berry <dp67@fedoraproject.org> - 1.3.0-2
- Build with $RPM_OPT_FLAGS bz #621371
- Remove unnecessary BuildRequires: desktop-file-utils
- Add additional man pages
- Added BuildRequires: zlib-devel for fontdata bz #621371
- Replace non-ascii characters in man pages

* Sun Aug  1 2010 Randall J. Berry <dp67@fedoraproject.org> - 1.3.0-1
- Upstream update 1.3.0
- Rebuild for F13/F14/Devel
- Clean up spec.
- Several files changed on newer version.

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.3-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Fri May  8 2009 Randall J. Berry <dp67@fedoraproject.org> - 1.2.3-6
- Update CVS
- Build with $RPM_OPT_FLAGS.
- Submit update fix bug #736499

* Thu May  7 2009 Ville Skyttä <ville.skytta at iki.fi> - 1.2.3-5
- Build with $RPM_OPT_FLAGS.

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Fri Dec 26 2008 Sindre Pedersen Bjørdal <sindrepb@fedoraproject.org> - 1.2.3-3
- fix broken obsoletes

* Sun Dec 22 2008 Sindre Pedersen Bjørdal <sindrepb@fedoraproject.org> - 1.2.3-2
- Merge main and -utils package, #475009

* Wed Jul 30 2008 Steve Conklin <fedora@conklinhouse.com> - 1.2.3-1
- New upstream
- added delivery of postdownload script and the new bearing utility
- added man pages for bearing and postdownload
* Thu Feb 28 2008 Steve Conklin <sconklin at redhat dot com> - 1.2.1-6
- Silly, there's no gui. Removed desktop and icon files.
* Thu Feb 28 2008 Steve Conklin <sconklin at redhat dot com> - 1.2.1-5
- installed desktop and icon files with main package, not utils

* Tue Feb 26 2008 Steve Conklin <sconklin at redhat dot com> - 1.2.1-4
- removed erroneous -march flag for ppc

* Mon Feb 25 2008 Steve Conklin <sconklin at redhat dot com> - 1.2.1-3
- Fixed declaration that the new gcc didn't like

* Tue Feb 19 2008 Steve Conklin <sconklin at redhat dot com> - 1.2.1-2
- Added desktop file and icon

* Sun Dec 09 2007 Sindre Pedersen Bjørdal - 1.2.1-1
- Initial Build
